@@ -11,5 +11,10 @@ class DiversityValidator(BaseValidator):
     of all logits.
     """
 
+    def __init__(self, layer="logits", **kwargs):
+        super().__init__(**kwargs)
+        self.layer = layer
+        self.loss_fn = DiversityLoss(after_softmax=self.layer == "preds")
+
     def compute_score(self, target_train):
-        return -DiversityLoss()(target_train["logits"]).item()
+        return -self.loss_fn(target_train[self.layer]).item()
